/*!	\file		Cicada.c
	\author		Garth Santor
	\date		2019-02-12
	\version	1.0.0

	Cycada Cycles solution in C.
*/

#include <stdio.h>
#include <stdlib.h>

const int kMaxCicadaCycles = 20;


/*!	Count the number of years that the cicada will coincide with predators.

	\param kCicadaCycle [in] the number of years in the cicada's life cycle.
	\param kTrialYears [in] the number of years to test against the cicada's cycle.
	\return the number of predators that align with the cicada's life cycle.
*/
int num_predators(const int kCicadaCycle, const int kTrialYears) {
	int predatorCount = 0;
	for (int year = 1; year <= kTrialYears; ++year) {
		if (year%kCicadaCycle == 0) {
			predatorCount += ((year % 2) == 0);
			predatorCount += ((year % 3) == 0);
			predatorCount += ((year % 4) == 0);
			predatorCount += ((year % 6) == 0);
		}
	}
	return predatorCount;
}


/*!	Process entry point - run the cicada trials.
*/
int main() {
	// Query the user for the number of trials to perform.
	printf("Enter the number of years to test: ");
	int trialYears;
	scanf_s("%d", &trialYears);

	// Output a table of trial results.
	puts("cicada cycle\t#predators");
	for (int cicadaCycle = 1; cicadaCycle <= kMaxCicadaCycles; ++cicadaCycle)
		printf("%d\t\t%d\n", cicadaCycle, num_predators(cicadaCycle, trialYears));

	return EXIT_SUCCESS;
}